@@ -5,11 +5,12 @@ void magnatune_db_destroy(void);
 void magnatune_db_init();
 void magnatune_db_open();
 gboolean magnatune_db_has_data();
-GList * magnatune_db_get_genre_list();
+MpdData * magnatune_db_get_genre_list();
 void magnatune_db_download_xml(ProgressCallback cb, gpointer data );
 gchar *magnatune_db_get_value(const char *artist, const char *album, int type);
-GList * magnatune_db_get_album_list(char *wanted_genre,char *wanted_artist);
-GList * magnatune_db_get_artist_list(char *genre);
+MpdData * magnatune_db_get_album_list(char *wanted_genre,char *wanted_artist);
+MpdData * magnatune_db_get_artist_list(char *genre);
 
 GList * magnatune_db_get_url_list(const char *wanted_genre,const char *wanted_artist, const char *wanted_album);
+MpdData* magnatune_db_get_song_list(const char *wanted_genre,const char *wanted_artist, const char *wanted_album);
 #endif
